@@ -1758,6 +1758,8 @@ static gint vnc_viewer_button_release_event(GtkWidget *widget,
   }
   g_message("button_release %d %d",x,y);
   vnc_viewer_queue_event(vnc, newPointerEventMsg(vnc->button_mask, x, y));
+  //fremantle
+  pm_button_for_toggle_fullscreen=FALSE;
   return TRUE;
 }
 
